@@ -36,7 +36,7 @@ from .objects.message import MessageGroup, factory_message
 from .objects.number_status import NumberStatus
 from .wapi_js_wrapper import WapiJsWrapper
 
-__version__ = '1.1.3'
+__version__ = '1.1.4'
 
 
 class WhatsAPIDriverStatus(object):
@@ -345,6 +345,12 @@ class WhatsAPIDriver(object):
         """
         return self.wapi_functions.setPresence(present)
 
+    def set_profile_status(self, status):
+        return self.wapi_functions.setMyStatus(status)
+
+    def set_profile_name(self, name):
+        return self.wapi_functions.setMyName(name)
+
     #################
     # QR
     #################
