@@ -1607,8 +1607,8 @@ window.WAPI.sendImage = async function (imgBase64, chatid, filename, caption, qu
  * @param newName - string the new name to set as profile name
  */
 window.WAPI.setMyName = async function (newName) {
-  if (!Store.Versions.default[11].BinaryProtocol) Store.Versions.default[11].BinaryProtocol = new Store.bp(11);
-  return await Store.Versions.default[11].setPushname(newName);
+  if (!Store.Base.BinaryProtocol) Store.Base.setSubProtocol(11);
+  return await Store.Base.setPushname(newName);
 }
 
 /** Change the icon for the group chat
